# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock_his.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import stock_comm_pb2 as stock__comm__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock_his.proto',
  package='MsgStockPull',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.release\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fstock_his.proto\x12\x0cMsgStockPull\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x10stock_comm.proto\"\xf7\x01\n\x11SubMarketPlateReq\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\'\n\x08language\x18\x02 \x01(\x0e\x32\x15.StockCommon.Language\x12\x19\n\x11subMarketCodeList\x18\x04 \x03(\t\x12\x15\n\rshowAllDetail\x18\x05 \x01(\r\x12\x0e\n\x06sorted\x18\x06 \x01(\r\x12\x33\n\x0bsortedFiled\x18\x07 \x03(\x0e\x32\x1e.MsgStockPull.QuotaSortedFiled\x12\x0f\n\x07\x63urrent\x18\x08 \x01(\r\x12\x0c\n\x04size\x18\t \x01(\r\"N\n\x12\x42\x61sicMarketInfoReq\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\x13\n\x0b\x61ssetIdList\x18\x03 \x03(\t\"U\n\x10HandicapQuotaReq\x12*\n\tstockCode\x18\x01 \x03(\x0b\x32\x17.MsgStockPull.StockCode\x12\x15\n\rshowAllDetail\x18\x02 \x01(\r\"g\n\tStockCode\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\'\n\x08language\x18\x03 \x01(\x0e\x32\x15.StockCommon.Language\"\xb9\x03\n\nWarrantReq\x12\x13\n\x0bwarrantType\x18\x01 \x03(\r\x12\x17\n\x0fmaturityDayType\x18\x02 \x03(\r\x12\x13\n\x0b\x63ompanyCode\x18\x03 \x03(\r\x12\x15\n\rmoneynessType\x18\x04 \x01(\r\x12\x11\n\tstrikeMin\x18\x05 \x01(\x01\x12\x11\n\tstrikeMax\x18\x06 \x01(\x01\x12\x12\n\npremiumMin\x18\x07 \x01(\x01\x12\x12\n\npremiumMax\x18\x08 \x01(\x01\x12\x19\n\x11percOfStillOutMin\x18\t \x01(\x01\x12\x19\n\x11percOfStillOutMax\x18\n \x01(\x01\x12\x0e\n\x06sorted\x18\x0b \x01(\r\x12\x33\n\x0bsortedFiled\x18\x0c \x03(\x0e\x32\x1e.MsgStockPull.QuotaSortedFiled\x12\x0f\n\x07\x63urrent\x18\r \x01(\r\x12\x0c\n\x04size\x18\x0e \x01(\r\x12\x0f\n\x07\x61ssetId\x18\x10 \x01(\t\x12\x15\n\rshowAllDetail\x18\x11 \x01(\r\x12\x15\n\rassetDetailId\x18\x12 \x03(\t\x12*\n\tstockCode\x18\x13 \x03(\x0b\x32\x17.MsgStockPull.StockCode\"9\n\x13WarrantAssetInfoReq\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x11\n\tshortName\x18\x02 \x01(\t\"p\n\x12TransactionStatReq\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\x11\n\tquoteDate\x18\x02 \x01(\t\x12\x0f\n\x07\x61ssetId\x18\x03 \x01(\t\x12\x11\n\ttransType\x18\x04 \x01(\r\"\x1e\n\nDicDataReq\x12\x10\n\x08\x64\x61taType\x18\x01 \x01(\t\"+\n\x0f\x45xchangeRateReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\"\xbb\x01\n\x08KLineReq\x12*\n\tstockCode\x18\x01 \x01(\x0b\x32\x17.MsgStockPull.StockCode\x12)\n\tquoteType\x18\x02 \x01(\x0e\x32\x16.StockCommon.QuoteType\x12\x15\n\radjFactorType\x18\x03 \x01(\r\x12\x11\n\tstartDate\x18\x04 \x01(\t\x12\x0f\n\x07\x65ndDate\x18\x05 \x01(\t\x12\x0f\n\x07\x63urrent\x18\x06 \x01(\r\x12\x0c\n\x04size\x18\x07 \x01(\r\"R\n\x07TickReq\x12*\n\tstockCode\x18\x01 \x01(\x0b\x32\x17.MsgStockPull.StockCode\x12\r\n\x05index\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"P\n\x0fMinuteQuotekReq\x12*\n\tstockCode\x18\x01 \x01(\x0b\x32\x17.MsgStockPull.StockCode\x12\x11\n\tdateCount\x18\x02 \x01(\r\"\xc2\x01\n\x0fKLineHistoryReq\x12*\n\tstockCode\x18\x01 \x03(\x0b\x32\x17.MsgStockPull.StockCode\x12)\n\tquoteType\x18\x02 \x01(\x0e\x32\x16.StockCommon.QuoteType\x12\x15\n\radjFactorType\x18\x03 \x01(\r\x12\x11\n\tstartDate\x18\x04 \x01(\t\x12\x0f\n\x07\x65ndDate\x18\x05 \x01(\t\x12\x0f\n\x07\x63urrent\x18\x06 \x01(\r\x12\x0c\n\x04size\x18\x07 \x01(\r\"\x7f\n\x0eTickHistoryReq\x12*\n\tstockCode\x18\x01 \x03(\x0b\x32\x17.MsgStockPull.StockCode\x12\x11\n\tstartDate\x18\x02 \x01(\t\x12\x0f\n\x07\x65ndDate\x18\x03 \x01(\t\x12\x0f\n\x07\x63urrent\x18\x04 \x01(\r\x12\x0c\n\x04size\x18\x05 \x01(\r\"t\n\x16SubMarketAssetInfoResp\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\x35\n\x0epagePlateQuota\x18\x02 \x03(\x0b\x32\x1d.MsgStockPull.IPagePlateQuota\"G\n\x11HandicapQuotaResp\x12\x32\n\rhandicapQuota\x18\x01 \x03(\x0b\x32\x1b.MsgStockPull.HandicapQuota\"\xd6\x02\n\rHandicapQuota\x12\x0f\n\x07\x61ssetId\x18\x02 \x01(\t\x12/\n\tassetInfo\x18\x03 \x01(\x0b\x32\x1c.MsgStockPull.BasicAssetInfo\x12\x33\n\x0b\x66inanceInfo\x18\x05 \x01(\x0b\x32\x1e.MsgStockPull.BasicFinanceInfo\x12/\n\tquoteInfo\x18\x06 \x01(\x0b\x32\x1c.MsgStockPull.BasicQuoteInfo\x12\x32\n\rotherQuotaExt\x18\x07 \x01(\x0b\x32\x1b.MsgStockPull.OtherQuotaExt\x12\x35\n\x0coneLevelInfo\x18\x08 \x01(\x0b\x32\x1f.MsgStockPull.OrderOneLevelInfo\x12\x32\n\rwarrantDetail\x18\t \x01(\x0b\x32\x1b.MsgStockPull.WarrantDetail\"\xae\x01\n\x13\x42\x61sicMarketInfoResp\x12#\n\x06market\x18\x01 \x01(\x0e\x32\x13.StockCommon.Market\x12\x34\n\x0e\x62\x61sicAssetInfo\x18\x03 \x03(\x0b\x32\x1c.MsgStockPull.BasicAssetInfo\x12<\n\x12\x62\x61sicSubMarketInfo\x18\x04 \x03(\x0b\x32 .MsgStockPull.BasicSubMarketInfo\"\x85\x01\n\x0bWarrantResp\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x03 \x01(\r\x12,\n\x07warrant\x18\x04 \x03(\x0b\x32\x1b.MsgStockPull.WarrantDetail\x12\x15\n\rshowAllDetail\x18\x05 \x01(\r\"\x86\x06\n\rWarrantDetail\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0b\n\x03now\x18\x02 \x01(\x01\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\x0e\n\x06\x63hange\x18\x04 \x01(\x01\x12\x11\n\tchangePct\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x01\x12\x10\n\x08tradeDay\x18\x07 \x01(\t\x12\x13\n\x0blastTradeDy\x18\x08 \x01(\t\x12\r\n\x05\x64\x65lta\x18\t \x01(\x01\x12\x14\n\x0ctargetCprice\x18\n \x01(\x01\x12\x16\n\x0e\x62reakEvenPrice\x18\x0b \x01(\x01\x12\x0f\n\x07premium\x18\x0c \x01(\x01\x12\x13\n\x0bmaturityDay\x18\r \x01(\t\x12\x16\n\x0epercOfStillOut\x18\x0e \x01(\x01\x12\x12\n\nstillOutNo\x18\x0f \x01(\x01\x12\x0e\n\x06strike\x18\x10 \x01(\x01\x12\x10\n\x08\x65ntRatio\x18\x11 \x01(\x01\x12\x17\n\x0fimplyVolatility\x18\x12 \x01(\x01\x12\x11\n\tpstrPrice\x18\x13 \x01(\x01\x12\x11\n\tmoneyness\x18\x14 \x01(\x01\x12\x15\n\rleverageRatio\x18\x15 \x01(\x01\x12\x18\n\x10\x65\x66\x66\x65\x63tiveGearing\x18\x16 \x01(\x01\x12\x1a\n\x12\x65xercisePriceFloor\x18\x17 \x01(\x01\x12\x1c\n\x14\x65xercisePriceCeiling\x18\x18 \x01(\x01\x12\x18\n\x10warrantCharacter\x18\x19 \x01(\r\x12\x13\n\x0b\x63ompanyCode\x18\x1a \x01(\r\x12\x0e\n\x06issuer\x18\x1b \x01(\t\x12\x10\n\x08issueVol\x18\x1c \x01(\x01\x12\x14\n\x0cminTradeSize\x18\x1d \x01(\r\x12\x36\n\x0fsimpleAssetInfo\x18\x1e \x01(\x0b\x32\x1d.MsgStockPull.SimpleAssetInfo\x12\x0c\n\x04open\x18\x1f \x01(\x01\x12\x0c\n\x04high\x18  \x01(\x01\x12\x0b\n\x03low\x18! \x01(\x01\x12\r\n\x05\x63lose\x18\" \x01(\x01\x12\x11\n\tlastClose\x18# \x01(\x01\x12\x11\n\tamplitude\x18$ \x01(\x01\x12\x15\n\rtargetAssetId\x18% \x01(\t\"\x98\x01\n\x14WarrantAssetInfoResp\x12\x46\n\x07warrant\x18\x04 \x03(\x0b\x32\x35.MsgStockPull.WarrantAssetInfoResp.WarrantAssetDetail\x1a\x38\n\x12WarrantAssetDetail\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x11\n\tshortName\x18\x02 \x01(\t\"\x9a\x01\n\x13TransactionStatResp\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x36\n\x0ftransactionStat\x18\x02 \x01(\x0b\x32\x1d.MsgStockPull.TransactionStat\x12:\n\x0ftransactionInfo\x18\x03 \x03(\x0b\x32!.MsgStockPull.TransactionStatList\";\n\x0b\x44icDataResp\x12,\n\x07\x64icData\x18\x01 \x03(\x0b\x32\x1b.MsgStockPull.DicDataDetail\"U\n\rDicDataDetail\x12\x10\n\x08\x64\x61taType\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taKey\x18\x02 \x01(\t\x12\x11\n\tdataValue\x18\x03 \x01(\t\x12\x0e\n\x06remark\x18\x04 \x01(\t\"\x95\x01\n\x0fTransactionStat\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0f\n\x07\x64\x65\x61lNum\x18\x02 \x01(\r\x12\x13\n\x0btotalVolume\x18\x03 \x01(\x04\x12\x14\n\x0cmiddleVolume\x18\x04 \x01(\x04\x12\x12\n\nsellVolume\x18\x05 \x01(\x04\x12\x11\n\tbuyVolume\x18\x06 \x01(\x04\x12\x10\n\x08tickTime\x18\x07 \x01(\x04\"v\n\x13TransactionStatList\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x13\n\x0btotalVolume\x18\x02 \x01(\x04\x12\x14\n\x0cmiddleVolume\x18\x03 \x01(\x04\x12\x12\n\nsellVolume\x18\x04 \x01(\x04\x12\x11\n\tbuyVolume\x18\x05 \x01(\x04\";\n\x0b\x41hQuotaResp\x12,\n\x07\x61hQuota\x18\x01 \x03(\x0b\x32\x1b.MsgStockPull.AhQuotaDetail\"\x95\x02\n\rAhQuotaDetail\x12\x11\n\thkAssetId\x18\x01 \x01(\t\x12\x11\n\tshortName\x18\x02 \x01(\t\x12\x11\n\thkStkCode\x18\x03 \x01(\t\x12\r\n\x05hkNow\x18\x04 \x01(\x01\x12\x13\n\x0bhkLastClose\x18\x05 \x01(\x01\x12\x10\n\x08hkChange\x18\x06 \x01(\x01\x12\x13\n\x0bhkChangePct\x18\x07 \x01(\x01\x12\x11\n\tcnAssetId\x18\x08 \x01(\t\x12\x11\n\tcnStkCode\x18\t \x01(\t\x12\r\n\x05\x63nNow\x18\n \x01(\x01\x12\x13\n\x0b\x63nLastClose\x18\x0b \x01(\x01\x12\x10\n\x08\x63nChange\x18\x0c \x01(\x01\x12\x13\n\x0b\x63nChangePct\x18\r \x01(\x01\x12\x0f\n\x07premium\x18\x0e \x01(\x01\"J\n\x10\x45xchangeRateResp\x12\x36\n\x0c\x65xchangeRate\x18\x01 \x03(\x0b\x32 .MsgStockPull.ExchangeRateDetail\"<\n\x12\x45xchangeRateDetail\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x01\"w\n\x0eKlineQuoteResp\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x03 \x01(\r\x12\x32\n\nklineQuote\x18\x04 \x03(\x0b\x32\x1e.MsgStockPull.KlineQuoteDetail\"\xef\x01\n\x10KlineQuoteDetail\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06market\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12\x0c\n\x04open\x18\x05 \x01(\x01\x12\x0c\n\x04high\x18\x06 \x01(\x01\x12\x0b\n\x03low\x18\x07 \x01(\x01\x12\r\n\x05\x63lose\x18\x08 \x01(\x01\x12\x11\n\tlastClose\x18\t \x01(\x01\x12\x0b\n\x03\x61vg\x18\n \x01(\x01\x12\x0e\n\x06\x63hange\x18\x0b \x01(\x01\x12\x11\n\tchangePct\x18\x0c \x01(\x01\x12\x0e\n\x06volume\x18\r \x01(\x04\x12\x0e\n\x06\x61mount\x18\x0e \x01(\x01\"U\n\x0fMinuteQuoteResp\x12\x11\n\tlastClose\x18\x01 \x01(\x01\x12/\n\x07minutes\x18\x02 \x03(\x0b\x32\x1e.MsgStockPull.KlineQuoteDetail\"R\n\x08TickResp\x12\x11\n\tlastClose\x18\x01 \x01(\x01\x12\x33\n\x11quoteTickRespList\x18\x02 \x03(\x0b\x32\x18.MsgStockPull.TickDetail\"\xaf\x01\n\nTickDetail\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x61ssetId\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06market\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x04\x12\x0b\n\x03now\x18\x06 \x01(\x01\x12\x11\n\tcurVolume\x18\x07 \x01(\r\x12\x0e\n\x06\x61mount\x18\x08 \x01(\x01\x12\x10\n\x08tickFlag\x18\t \x01(\r\x12\x0e\n\x06tickVi\x18\n \x01(\t\"p\n\x0fTickHistoryResp\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x03 \x01(\r\x12*\n\x08tickList\x18\x04 \x03(\x0b\x32\x18.MsgStockPull.TickDetail\"\x99\x01\n\x0f\x42uySellListResp\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06market\x18\x03 \x01(\t\x12*\n\x07\x62uyList\x18\x04 \x03(\x0b\x32\x19.MsgStockPull.BuySellList\x12+\n\x08sellList\x18\x05 \x03(\x0b\x32\x19.MsgStockPull.BuySellList\"P\n\x0b\x42uySellList\x12\r\n\x05level\x18\x01 \x01(\r\x12\x13\n\x0b\x62rokerCount\x18\x02 \x01(\r\x12\r\n\x05price\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x04\"\xaf\x01\n\x13QuoteInfoBrokerResp\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06market\x18\x03 \x01(\t\x12\x33\n\x07\x62uyList\x18\x04 \x03(\x0b\x32\".MsgStockPull.QuoteInfoBrokerStall\x12\x34\n\x08sellList\x18\x05 \x03(\x0b\x32\".MsgStockPull.QuoteInfoBrokerStall\"c\n\x14QuoteInfoBrokerStall\x12\x13\n\x0b\x62rokerLevel\x18\x01 \x01(\r\x12\x36\n\x0b\x62rokerInfos\x18\x02 \x03(\x0b\x32!.MsgStockPull.QuoteInfoBrokerInfo\";\n\x13QuoteInfoBrokerInfo\x12\x10\n\x08\x62rokerId\x18\x01 \x01(\t\x12\x12\n\nbrokerName\x18\x02 \x01(\t\"\x89\x01\n\x0fIPagePlateQuota\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x12\n\ntotalCount\x18\x04 \x01(\r\x12\x15\n\rsubMarketCode\x18\x05 \x01(\t\x12,\n\nplateQuota\x18\x07 \x03(\x0b\x32\x18.MsgStockPull.PlateQuota\"\xb7\x01\n\nPlateQuota\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12.\n\x0b\x63ommonQuota\x18\x02 \x01(\x0b\x32\x19.MsgStockPull.CommonQuota\x12\x30\n\x0cpopularQuota\x18\x03 \x01(\x0b\x32\x1a.MsgStockPull.PopularQuota\x12\x36\n\x0fsimpleAssetInfo\x18\x04 \x01(\x0b\x32\x1d.MsgStockPull.SimpleAssetInfo\"\xf1\x01\n\x0cPopularQuota\x12\x12\n\nsubPlateId\x18\x01 \x01(\t\x12\x14\n\x0csubPlateCode\x18\x02 \x01(\t\x12\x14\n\x0csubPlateName\x18\x03 \x01(\t\x12\x11\n\tchangePct\x18\x04 \x01(\x01\x12\x0e\n\x06\x63hange\x18\x05 \x01(\x01\x12\x0f\n\x07stkCode\x18\x06 \x01(\t\x12\x11\n\tshortName\x18\x07 \x01(\t\x12\x14\n\x0c\x61vgChangePct\x18\x08 \x01(\x01\x12\x16\n\x0e\x66latPlateCount\x18\t \x01(\r\x12\x14\n\x0cupPlateCount\x18\n \x01(\r\x12\x16\n\x0e\x64ownPlateCount\x18\x0b \x01(\r\"\xc2\x01\n\x0b\x43ommonQuota\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x30\n\nbasicQuote\x18\x02 \x01(\x0b\x32\x1c.MsgStockPull.BasicQuoteInfo\x12<\n\x12\x63ommonFinanceQuota\x18\x03 \x01(\x0b\x32 .MsgStockPull.CommonFinanceQuota\x12\x32\n\rotherQuotaExt\x18\x04 \x01(\x0b\x32\x1b.MsgStockPull.OtherQuotaExt\"\xa1\x01\n\rOtherQuotaExt\x12\x11\n\touterDisk\x18\x01 \x01(\x01\x12\x11\n\tinnerDisk\x18\x02 \x01(\x01\x12\x11\n\trisePrice\x18\x03 \x01(\x01\x12\x11\n\tfallPrice\x18\x04 \x01(\x01\x12\x16\n\x0e\x66latPlateCount\x18\x05 \x01(\x05\x12\x14\n\x0cupPlateCount\x18\x06 \x01(\x05\x12\x16\n\x0e\x64ownPlateCount\x18\x07 \x01(\x05\"\xe1\x01\n\x10\x42\x61sicFinanceInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x14\n\x0cshareCapital\x18\x02 \x01(\x04\x12\x1a\n\x12\x63irculationCapital\x18\x03 \x01(\x04\x12\x19\n\x11\x65\x61rningsPerShares\x18\x04 \x01(\x01\x12\x12\n\nnetAssetPS\x18\x05 \x01(\x01\x12\x1d\n\x15\x64ividendPerShareTotal\x18\x06 \x01(\x01\x12<\n\x12\x63ommonFinanceQuota\x18\x07 \x01(\x0b\x32 .MsgStockPull.CommonFinanceQuota\"\xa7\x02\n\x12\x43ommonFinanceQuota\x12\x13\n\x0bmarketValue\x18\x01 \x01(\x01\x12\x14\n\x0cturnoverRate\x18\x02 \x01(\x01\x12\x0f\n\x07peRatio\x18\x03 \x01(\x01\x12\x12\n\npeRatioTTM\x18\x04 \x01(\x01\x12\x0f\n\x07pbRatio\x18\x05 \x01(\x01\x12\x15\n\rquantityRatio\x18\x06 \x01(\x01\x12\x11\n\tcommittee\x18\x07 \x01(\x01\x12\x11\n\tamplitude\x18\x08 \x01(\x01\x12\x17\n\x0fnegotiableValue\x18\t \x01(\x01\x12\x18\n\x10\x64ividendPerShare\x18\n \x01(\x01\x12\x15\n\rdividendRatio\x18\x0b \x01(\x01\x12\x14\n\x0chighIn52Week\x18\x0c \x01(\x01\x12\x13\n\x0blowIn52Week\x18\r \x01(\x01\"\xc6\x05\n\x0e\x42\x61sicQuoteInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x0b\n\x03now\x18\x02 \x01(\x01\x12\x0c\n\x04open\x18\x03 \x01(\x01\x12\x0c\n\x04high\x18\x04 \x01(\x01\x12\x0b\n\x03low\x18\x05 \x01(\x01\x12\r\n\x05\x63lose\x18\x06 \x01(\x01\x12\x11\n\tlastClose\x18\x07 \x01(\x01\x12\x0e\n\x06volume\x18\x08 \x01(\x04\x12\x0e\n\x06\x61mount\x18\t \x01(\x01\x12\x10\n\x08\x61vgPrice\x18\n \x01(\x01\x12\x12\n\nchangeRate\x18\x0b \x01(\x01\x12 \n\x18perVolumeInLast5TradeDay\x18\x0c \x01(\x01\x12\x11\n\tchangePct\x18\r \x01(\x01\x12\x0e\n\x06\x63hange\x18\x0e \x01(\x01\x12\x13\n\x0bstockStatus\x18\x0f \x01(\r\x12\x11\n\tstockTime\x18\x10 \x01(\t\x12\x13\n\x0bthisYearPct\x18\x11 \x01(\x01\x12\x14\n\x0cthisMonthPct\x18\x12 \x01(\x01\x12\x15\n\rlastYearClose\x18\x13 \x01(\x01\x12\x16\n\x0elastMonthClose\x18\x14 \x01(\x01\x12\x14\n\x0cpre5MinPrice\x18\x15 \x01(\x01\x12\x15\n\rlastClose5Day\x18\x16 \x01(\x01\x12\x16\n\x0elastClose10Day\x18\x17 \x01(\x01\x12\x16\n\x0elastClose20Day\x18\x18 \x01(\x01\x12\x16\n\x0elastClose60Day\x18\x19 \x01(\x01\x12\x17\n\x0flastClose120Day\x18\x1a \x01(\x01\x12\x17\n\x0flastClose250Day\x18\x1b \x01(\x01\x12\x18\n\x10\x63hangePct5Minute\x18\x1c \x01(\x01\x12\x12\n\nchangePct5\x18\x1d \x01(\x01\x12\x13\n\x0b\x63hangePct10\x18\x1e \x01(\x01\x12\x13\n\x0b\x63hangePct20\x18\x1f \x01(\x01\x12\x13\n\x0b\x63hangePct60\x18  \x01(\x01\x12\x14\n\x0c\x63hangePct120\x18! \x01(\x01\x12\x14\n\x0c\x63hangePct250\x18\" \x01(\x01\"\x98\x02\n\x0e\x42\x61sicAssetInfo\x12\x0f\n\x07\x61ssetId\x18\x01 \x01(\t\x12\x11\n\tshortName\x18\x02 \x01(\t\x12\x0f\n\x07stkCode\x18\x03 \x01(\t\x12\x0f\n\x07lotSize\x18\x04 \x01(\r\x12\x12\n\nstatusFlag\x18\x05 \x01(\r\x12\x13\n\x0blistingDate\x18\x06 \x01(\x03\x12\x15\n\rdelistingDate\x18\x07 \x01(\x03\x12\x14\n\x0cpriceDecimal\x18\x08 \x01(\r\x12\x15\n\rsubMarketCode\x18\t \x01(\t\x12\x15\n\rsubMarketName\x18\n \x01(\t\x12\x14\n\x0c\x65xchangeCode\x18\x0b \x01(\t\x12\x14\n\x0c\x65xchangeName\x18\x0c \x01(\t\x12\x10\n\x08industry\x18\r \x01(\t\"R\n\x0fSimpleAssetInfo\x12\x11\n\tshortName\x18\x01 \x01(\t\x12\x15\n\rsubMarketCode\x18\x02 \x01(\r\x12\x15\n\rsubMarketName\x18\x03 \x01(\t\"\x95\x01\n\x11\x42\x61sicAssetInfoExt\x12\x15\n\rsubMarketCode\x18\x01 \x01(\r\x12\x15\n\rsubMarketName\x18\x02 \x01(\t\x12\x12\n\nmarketCode\x18\x03 \x01(\r\x12\x12\n\nmarketName\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangeCode\x18\x05 \x01(\t\x12\x14\n\x0c\x65xchangeName\x18\x06 \x01(\t\"\xbc\x01\n\x12\x42\x61sicSubMarketInfo\x12\x12\n\nmarketName\x18\x02 \x01(\t\x12\x15\n\rsubMarketCode\x18\x03 \x01(\t\x12\x15\n\rsubMarketName\x18\x04 \x01(\t\x12\x17\n\x0fsubMarketEnName\x18\x05 \x01(\t\x12\x17\n\x0fSubMarketTrName\x18\x06 \x01(\t\x12\x32\n\rsubMarketTime\x18\x07 \x01(\x0b\x32\x1b.MsgStockPull.SubMarketTime\"z\n\rSubMarketTime\x12\r\n\x05\x63lear\x18\x01 \x01(\r\x12\x0c\n\x04open\x18\x02 \x01(\r\x12\x11\n\ttime_zone\x18\x03 \x01(\r\x12*\n\ttradeTime\x18\x04 \x03(\x0b\x32\x17.MsgStockPull.TradeTime\x12\r\n\x05\x63lose\x18\x05 \x01(\r\"3\n\tTradeTime\x12\x13\n\x0btrade_start\x18\x01 \x01(\r\x12\x11\n\ttrade_end\x18\x02 \x01(\r\"_\n\x11OrderOneLevelInfo\x12\x10\n\x08\x62uyPrice\x18\x01 \x01(\x01\x12\x11\n\tbuyVolume\x18\x02 \x01(\x04\x12\x11\n\tsellPrice\x18\x03 \x01(\x01\x12\x12\n\nsellVolume\x18\x04 \x01(\x04*\xe5\x07\n\x10QuotaSortedFiled\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03now\x10\x01\x12\r\n\tchangePct\x10\x02\x12\n\n\x06\x63hange\x10\x03\x12\x0e\n\nchangeRate\x10\x04\x12\n\n\x06volume\x10\x05\x12\n\n\x06\x61mount\x10\x06\x12\x10\n\x0cturnoverRate\x10\x07\x12\x0b\n\x07peRatio\x10\x08\x12\x0b\n\x07pbRatio\x10\t\x12\r\n\tamplitude\x10\n\x12\x13\n\x0fnegotiableValue\x10\x0b\x12\x0f\n\x0bmarketValue\x10\x0c\x12\x11\n\rquantityRatio\x10\r\x12\r\n\tcommittee\x10\x0e\x12\x0f\n\x0bmaturityDay\x10\x0f\x12\n\n\x06strike\x10\x10\x12\x14\n\x10\x65\x66\x66\x65\x63tiveGearing\x10\x11\x12\x11\n\rleverageRatio\x10\x12\x12\x0b\n\x07premium\x10\x13\x12\r\n\tpstrPrice\x10\x14\x12\r\n\tmoneyness\x10\x15\x12\x12\n\x0epercOfStillOut\x10\x16\x12\x16\n\x12\x65xercisePriceFloor\x10\x17\x12\x18\n\x14\x65xercisePriceCeiling\x10\x18\x12\x13\n\x0fimplyVolatility\x10\x19\x12\x0c\n\x08\x65ntRatio\x10\x1a\x12\n\n\x06status\x10\x1b\x12\x0e\n\npeRatioTTM\x10\x1c\x12\x10\n\x0clastTradeDay\x10\x1d\x12\x10\n\x0ctargetCprice\x10\x1e\x12\x12\n\x0e\x62reakEvenPrice\x10\x1f\x12\x0e\n\nstillOutNo\x10 \x12\x14\n\x10warrantCharacter\x10!\x12\n\n\x06issuer\x10\"\x12\x0c\n\x08issueVol\x10#\x12\x10\n\x0cminTradeSize\x10$\x12\x0f\n\x0blistingDate\x10%\x12\x0c\n\x08\x62uyPrice\x10&\x12\r\n\tsellPrice\x10\'\x12\r\n\tbuyVolume\x10(\x12\x0e\n\nsellVolume\x10)\x12\r\n\tlastClose\x10*\x12\x08\n\x04open\x10+\x12\x08\n\x04high\x10,\x12\x07\n\x03low\x10-\x12\x10\n\x0cshareCapital\x10.\x12\x16\n\x12\x63irculationCapital\x10/\x12\x14\n\x10\x63hangePct5Minute\x10\x30\x12\x0e\n\nchangePct5\x10\x31\x12\x0f\n\x0b\x63hangePct10\x10\x32\x12\x0f\n\x0b\x63hangePct20\x10\x33\x12\x0f\n\x0b\x63hangePct60\x10\x34\x12\x10\n\x0c\x63hangePct120\x10\x35\x12\x10\n\x0c\x63hangePct250\x10\x36\x12\x0f\n\x0bthisYearPct\x10\x37\x12\x10\n\x0cthisMonthPct\x10\x38\x12\x14\n\x10\x64ividendPerShare\x10\x39\x12\x11\n\rdividendRatio\x10:\x12\x0c\n\x08industry\x10;B.\n#com.kaisaglobal.proto.stock.release\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stock__comm__pb2.DESCRIPTOR,])

_QUOTASORTEDFILED = _descriptor.EnumDescriptor(
  name='QuotaSortedFiled',
  full_name='MsgStockPull.QuotaSortedFiled',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='now', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='change', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changeRate', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='volume', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amount', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='turnoverRate', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='peRatio', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pbRatio', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amplitude', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='negotiableValue', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='marketValue', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='quantityRatio', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='committee', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='maturityDay', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='strike', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='effectiveGearing', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='leverageRatio', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='premium', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pstrPrice', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='moneyness', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='percOfStillOut', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='exercisePriceFloor', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='exercisePriceCeiling', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='implyVolatility', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='entRatio', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='status', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='peRatioTTM', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='lastTradeDay', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='targetCprice', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='breakEvenPrice', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='stillOutNo', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='warrantCharacter', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='issuer', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='issueVol', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='minTradeSize', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='listingDate', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='buyPrice', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sellPrice', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='buyVolume', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sellVolume', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='lastClose', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='open', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='high', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='low', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='shareCapital', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='circulationCapital', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct5Minute', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct5', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct10', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct20', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct60', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct120', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='changePct250', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='thisYearPct', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='thisMonthPct', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='dividendPerShare', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='dividendRatio', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='industry', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9378,
  serialized_end=10375,
)
_sym_db.RegisterEnumDescriptor(_QUOTASORTEDFILED)

QuotaSortedFiled = enum_type_wrapper.EnumTypeWrapper(_QUOTASORTEDFILED)
NONE = 0
now = 1
changePct = 2
change = 3
changeRate = 4
volume = 5
amount = 6
turnoverRate = 7
peRatio = 8
pbRatio = 9
amplitude = 10
negotiableValue = 11
marketValue = 12
quantityRatio = 13
committee = 14
maturityDay = 15
strike = 16
effectiveGearing = 17
leverageRatio = 18
premium = 19
pstrPrice = 20
moneyness = 21
percOfStillOut = 22
exercisePriceFloor = 23
exercisePriceCeiling = 24
implyVolatility = 25
entRatio = 26
status = 27
peRatioTTM = 28
lastTradeDay = 29
targetCprice = 30
breakEvenPrice = 31
stillOutNo = 32
warrantCharacter = 33
issuer = 34
issueVol = 35
minTradeSize = 36
listingDate = 37
buyPrice = 38
sellPrice = 39
buyVolume = 40
sellVolume = 41
lastClose = 42
open = 43
high = 44
low = 45
shareCapital = 46
circulationCapital = 47
changePct5Minute = 48
changePct5 = 49
changePct10 = 50
changePct20 = 51
changePct60 = 52
changePct120 = 53
changePct250 = 54
thisYearPct = 55
thisMonthPct = 56
dividendPerShare = 57
dividendRatio = 58
industry = 59



_SUBMARKETPLATEREQ = _descriptor.Descriptor(
  name='SubMarketPlateReq',
  full_name='MsgStockPull.SubMarketPlateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.SubMarketPlateReq.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='MsgStockPull.SubMarketPlateReq.language', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCodeList', full_name='MsgStockPull.SubMarketPlateReq.subMarketCodeList', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showAllDetail', full_name='MsgStockPull.SubMarketPlateReq.showAllDetail', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sorted', full_name='MsgStockPull.SubMarketPlateReq.sorted', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortedFiled', full_name='MsgStockPull.SubMarketPlateReq.sortedFiled', index=5,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.SubMarketPlateReq.current', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.SubMarketPlateReq.size', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=332,
)


_BASICMARKETINFOREQ = _descriptor.Descriptor(
  name='BasicMarketInfoReq',
  full_name='MsgStockPull.BasicMarketInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.BasicMarketInfoReq.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetIdList', full_name='MsgStockPull.BasicMarketInfoReq.assetIdList', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=412,
)


_HANDICAPQUOTAREQ = _descriptor.Descriptor(
  name='HandicapQuotaReq',
  full_name='MsgStockPull.HandicapQuotaReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.HandicapQuotaReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showAllDetail', full_name='MsgStockPull.HandicapQuotaReq.showAllDetail', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=499,
)


_STOCKCODE = _descriptor.Descriptor(
  name='StockCode',
  full_name='MsgStockPull.StockCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.StockCode.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.StockCode.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='MsgStockPull.StockCode.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=604,
)


_WARRANTREQ = _descriptor.Descriptor(
  name='WarrantReq',
  full_name='MsgStockPull.WarrantReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warrantType', full_name='MsgStockPull.WarrantReq.warrantType', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturityDayType', full_name='MsgStockPull.WarrantReq.maturityDayType', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyCode', full_name='MsgStockPull.WarrantReq.companyCode', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moneynessType', full_name='MsgStockPull.WarrantReq.moneynessType', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikeMin', full_name='MsgStockPull.WarrantReq.strikeMin', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strikeMax', full_name='MsgStockPull.WarrantReq.strikeMax', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premiumMin', full_name='MsgStockPull.WarrantReq.premiumMin', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premiumMax', full_name='MsgStockPull.WarrantReq.premiumMax', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOutMin', full_name='MsgStockPull.WarrantReq.percOfStillOutMin', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOutMax', full_name='MsgStockPull.WarrantReq.percOfStillOutMax', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sorted', full_name='MsgStockPull.WarrantReq.sorted', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sortedFiled', full_name='MsgStockPull.WarrantReq.sortedFiled', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.WarrantReq.current', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.WarrantReq.size', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.WarrantReq.assetId', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showAllDetail', full_name='MsgStockPull.WarrantReq.showAllDetail', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetDetailId', full_name='MsgStockPull.WarrantReq.assetDetailId', index=16,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.WarrantReq.stockCode', index=17,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=1048,
)


_WARRANTASSETINFOREQ = _descriptor.Descriptor(
  name='WarrantAssetInfoReq',
  full_name='MsgStockPull.WarrantAssetInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.WarrantAssetInfoReq.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.WarrantAssetInfoReq.shortName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1107,
)


_TRANSACTIONSTATREQ = _descriptor.Descriptor(
  name='TransactionStatReq',
  full_name='MsgStockPull.TransactionStatReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.TransactionStatReq.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteDate', full_name='MsgStockPull.TransactionStatReq.quoteDate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.TransactionStatReq.assetId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transType', full_name='MsgStockPull.TransactionStatReq.transType', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1221,
)


_DICDATAREQ = _descriptor.Descriptor(
  name='DicDataReq',
  full_name='MsgStockPull.DicDataReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataType', full_name='MsgStockPull.DicDataReq.dataType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1223,
  serialized_end=1253,
)


_EXCHANGERATEREQ = _descriptor.Descriptor(
  name='ExchangeRateReq',
  full_name='MsgStockPull.ExchangeRateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='MsgStockPull.ExchangeRateReq.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='MsgStockPull.ExchangeRateReq.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1298,
)


_KLINEREQ = _descriptor.Descriptor(
  name='KLineReq',
  full_name='MsgStockPull.KLineReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.KLineReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteType', full_name='MsgStockPull.KLineReq.quoteType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjFactorType', full_name='MsgStockPull.KLineReq.adjFactorType', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startDate', full_name='MsgStockPull.KLineReq.startDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endDate', full_name='MsgStockPull.KLineReq.endDate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.KLineReq.current', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.KLineReq.size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1301,
  serialized_end=1488,
)


_TICKREQ = _descriptor.Descriptor(
  name='TickReq',
  full_name='MsgStockPull.TickReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.TickReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='MsgStockPull.TickReq.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.TickReq.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1572,
)


_MINUTEQUOTEKREQ = _descriptor.Descriptor(
  name='MinuteQuotekReq',
  full_name='MsgStockPull.MinuteQuotekReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.MinuteQuotekReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dateCount', full_name='MsgStockPull.MinuteQuotekReq.dateCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1574,
  serialized_end=1654,
)


_KLINEHISTORYREQ = _descriptor.Descriptor(
  name='KLineHistoryReq',
  full_name='MsgStockPull.KLineHistoryReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.KLineHistoryReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteType', full_name='MsgStockPull.KLineHistoryReq.quoteType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjFactorType', full_name='MsgStockPull.KLineHistoryReq.adjFactorType', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startDate', full_name='MsgStockPull.KLineHistoryReq.startDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endDate', full_name='MsgStockPull.KLineHistoryReq.endDate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.KLineHistoryReq.current', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.KLineHistoryReq.size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1851,
)


_TICKHISTORYREQ = _descriptor.Descriptor(
  name='TickHistoryReq',
  full_name='MsgStockPull.TickHistoryReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCode', full_name='MsgStockPull.TickHistoryReq.stockCode', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startDate', full_name='MsgStockPull.TickHistoryReq.startDate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endDate', full_name='MsgStockPull.TickHistoryReq.endDate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.TickHistoryReq.current', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.TickHistoryReq.size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1853,
  serialized_end=1980,
)


_SUBMARKETASSETINFORESP = _descriptor.Descriptor(
  name='SubMarketAssetInfoResp',
  full_name='MsgStockPull.SubMarketAssetInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.SubMarketAssetInfoResp.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagePlateQuota', full_name='MsgStockPull.SubMarketAssetInfoResp.pagePlateQuota', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2098,
)


_HANDICAPQUOTARESP = _descriptor.Descriptor(
  name='HandicapQuotaResp',
  full_name='MsgStockPull.HandicapQuotaResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handicapQuota', full_name='MsgStockPull.HandicapQuotaResp.handicapQuota', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2171,
)


_HANDICAPQUOTA = _descriptor.Descriptor(
  name='HandicapQuota',
  full_name='MsgStockPull.HandicapQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.HandicapQuota.assetId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetInfo', full_name='MsgStockPull.HandicapQuota.assetInfo', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='financeInfo', full_name='MsgStockPull.HandicapQuota.financeInfo', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteInfo', full_name='MsgStockPull.HandicapQuota.quoteInfo', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otherQuotaExt', full_name='MsgStockPull.HandicapQuota.otherQuotaExt', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneLevelInfo', full_name='MsgStockPull.HandicapQuota.oneLevelInfo', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrantDetail', full_name='MsgStockPull.HandicapQuota.warrantDetail', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2516,
)


_BASICMARKETINFORESP = _descriptor.Descriptor(
  name='BasicMarketInfoResp',
  full_name='MsgStockPull.BasicMarketInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.BasicMarketInfoResp.market', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicAssetInfo', full_name='MsgStockPull.BasicMarketInfoResp.basicAssetInfo', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicSubMarketInfo', full_name='MsgStockPull.BasicMarketInfoResp.basicSubMarketInfo', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2519,
  serialized_end=2693,
)


_WARRANTRESP = _descriptor.Descriptor(
  name='WarrantResp',
  full_name='MsgStockPull.WarrantResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.WarrantResp.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.WarrantResp.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.WarrantResp.totalCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrant', full_name='MsgStockPull.WarrantResp.warrant', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showAllDetail', full_name='MsgStockPull.WarrantResp.showAllDetail', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2829,
)


_WARRANTDETAIL = _descriptor.Descriptor(
  name='WarrantDetail',
  full_name='MsgStockPull.WarrantDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.WarrantDetail.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockPull.WarrantDetail.now', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.WarrantDetail.amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.WarrantDetail.change', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.WarrantDetail.changePct', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.WarrantDetail.volume', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradeDay', full_name='MsgStockPull.WarrantDetail.tradeDay', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTradeDy', full_name='MsgStockPull.WarrantDetail.lastTradeDy', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta', full_name='MsgStockPull.WarrantDetail.delta', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetCprice', full_name='MsgStockPull.WarrantDetail.targetCprice', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='breakEvenPrice', full_name='MsgStockPull.WarrantDetail.breakEvenPrice', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premium', full_name='MsgStockPull.WarrantDetail.premium', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturityDay', full_name='MsgStockPull.WarrantDetail.maturityDay', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percOfStillOut', full_name='MsgStockPull.WarrantDetail.percOfStillOut', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stillOutNo', full_name='MsgStockPull.WarrantDetail.stillOutNo', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strike', full_name='MsgStockPull.WarrantDetail.strike', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entRatio', full_name='MsgStockPull.WarrantDetail.entRatio', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implyVolatility', full_name='MsgStockPull.WarrantDetail.implyVolatility', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pstrPrice', full_name='MsgStockPull.WarrantDetail.pstrPrice', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moneyness', full_name='MsgStockPull.WarrantDetail.moneyness', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leverageRatio', full_name='MsgStockPull.WarrantDetail.leverageRatio', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effectiveGearing', full_name='MsgStockPull.WarrantDetail.effectiveGearing', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercisePriceFloor', full_name='MsgStockPull.WarrantDetail.exercisePriceFloor', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exercisePriceCeiling', full_name='MsgStockPull.WarrantDetail.exercisePriceCeiling', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrantCharacter', full_name='MsgStockPull.WarrantDetail.warrantCharacter', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyCode', full_name='MsgStockPull.WarrantDetail.companyCode', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='MsgStockPull.WarrantDetail.issuer', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issueVol', full_name='MsgStockPull.WarrantDetail.issueVol', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minTradeSize', full_name='MsgStockPull.WarrantDetail.minTradeSize', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simpleAssetInfo', full_name='MsgStockPull.WarrantDetail.simpleAssetInfo', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.WarrantDetail.open', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='MsgStockPull.WarrantDetail.high', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='MsgStockPull.WarrantDetail.low', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='MsgStockPull.WarrantDetail.close', index=33,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.WarrantDetail.lastClose', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='MsgStockPull.WarrantDetail.amplitude', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAssetId', full_name='MsgStockPull.WarrantDetail.targetAssetId', index=36,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2832,
  serialized_end=3606,
)


_WARRANTASSETINFORESP_WARRANTASSETDETAIL = _descriptor.Descriptor(
  name='WarrantAssetDetail',
  full_name='MsgStockPull.WarrantAssetInfoResp.WarrantAssetDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.WarrantAssetInfoResp.WarrantAssetDetail.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.WarrantAssetInfoResp.WarrantAssetDetail.shortName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3705,
  serialized_end=3761,
)

_WARRANTASSETINFORESP = _descriptor.Descriptor(
  name='WarrantAssetInfoResp',
  full_name='MsgStockPull.WarrantAssetInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warrant', full_name='MsgStockPull.WarrantAssetInfoResp.warrant', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WARRANTASSETINFORESP_WARRANTASSETDETAIL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3761,
)


_TRANSACTIONSTATRESP = _descriptor.Descriptor(
  name='TransactionStatResp',
  full_name='MsgStockPull.TransactionStatResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.TransactionStatResp.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactionStat', full_name='MsgStockPull.TransactionStatResp.transactionStat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactionInfo', full_name='MsgStockPull.TransactionStatResp.transactionInfo', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3764,
  serialized_end=3918,
)


_DICDATARESP = _descriptor.Descriptor(
  name='DicDataResp',
  full_name='MsgStockPull.DicDataResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dicData', full_name='MsgStockPull.DicDataResp.dicData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3920,
  serialized_end=3979,
)


_DICDATADETAIL = _descriptor.Descriptor(
  name='DicDataDetail',
  full_name='MsgStockPull.DicDataDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataType', full_name='MsgStockPull.DicDataDetail.dataType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataKey', full_name='MsgStockPull.DicDataDetail.dataKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataValue', full_name='MsgStockPull.DicDataDetail.dataValue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remark', full_name='MsgStockPull.DicDataDetail.remark', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3981,
  serialized_end=4066,
)


_TRANSACTIONSTAT = _descriptor.Descriptor(
  name='TransactionStat',
  full_name='MsgStockPull.TransactionStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='MsgStockPull.TransactionStat.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dealNum', full_name='MsgStockPull.TransactionStat.dealNum', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalVolume', full_name='MsgStockPull.TransactionStat.totalVolume', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middleVolume', full_name='MsgStockPull.TransactionStat.middleVolume', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellVolume', full_name='MsgStockPull.TransactionStat.sellVolume', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buyVolume', full_name='MsgStockPull.TransactionStat.buyVolume', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickTime', full_name='MsgStockPull.TransactionStat.tickTime', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4069,
  serialized_end=4218,
)


_TRANSACTIONSTATLIST = _descriptor.Descriptor(
  name='TransactionStatList',
  full_name='MsgStockPull.TransactionStatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='MsgStockPull.TransactionStatList.price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalVolume', full_name='MsgStockPull.TransactionStatList.totalVolume', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middleVolume', full_name='MsgStockPull.TransactionStatList.middleVolume', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellVolume', full_name='MsgStockPull.TransactionStatList.sellVolume', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buyVolume', full_name='MsgStockPull.TransactionStatList.buyVolume', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4220,
  serialized_end=4338,
)


_AHQUOTARESP = _descriptor.Descriptor(
  name='AhQuotaResp',
  full_name='MsgStockPull.AhQuotaResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ahQuota', full_name='MsgStockPull.AhQuotaResp.ahQuota', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4340,
  serialized_end=4399,
)


_AHQUOTADETAIL = _descriptor.Descriptor(
  name='AhQuotaDetail',
  full_name='MsgStockPull.AhQuotaDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hkAssetId', full_name='MsgStockPull.AhQuotaDetail.hkAssetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.AhQuotaDetail.shortName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hkStkCode', full_name='MsgStockPull.AhQuotaDetail.hkStkCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hkNow', full_name='MsgStockPull.AhQuotaDetail.hkNow', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hkLastClose', full_name='MsgStockPull.AhQuotaDetail.hkLastClose', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hkChange', full_name='MsgStockPull.AhQuotaDetail.hkChange', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hkChangePct', full_name='MsgStockPull.AhQuotaDetail.hkChangePct', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnAssetId', full_name='MsgStockPull.AhQuotaDetail.cnAssetId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnStkCode', full_name='MsgStockPull.AhQuotaDetail.cnStkCode', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnNow', full_name='MsgStockPull.AhQuotaDetail.cnNow', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnLastClose', full_name='MsgStockPull.AhQuotaDetail.cnLastClose', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnChange', full_name='MsgStockPull.AhQuotaDetail.cnChange', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cnChangePct', full_name='MsgStockPull.AhQuotaDetail.cnChangePct', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premium', full_name='MsgStockPull.AhQuotaDetail.premium', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4402,
  serialized_end=4679,
)


_EXCHANGERATERESP = _descriptor.Descriptor(
  name='ExchangeRateResp',
  full_name='MsgStockPull.ExchangeRateResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchangeRate', full_name='MsgStockPull.ExchangeRateResp.exchangeRate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4681,
  serialized_end=4755,
)


_EXCHANGERATEDETAIL = _descriptor.Descriptor(
  name='ExchangeRateDetail',
  full_name='MsgStockPull.ExchangeRateDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='MsgStockPull.ExchangeRateDetail.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='MsgStockPull.ExchangeRateDetail.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='MsgStockPull.ExchangeRateDetail.rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4757,
  serialized_end=4817,
)


_KLINEQUOTERESP = _descriptor.Descriptor(
  name='KlineQuoteResp',
  full_name='MsgStockPull.KlineQuoteResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.KlineQuoteResp.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.KlineQuoteResp.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.KlineQuoteResp.totalCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='klineQuote', full_name='MsgStockPull.KlineQuoteResp.klineQuote', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4819,
  serialized_end=4938,
)


_KLINEQUOTEDETAIL = _descriptor.Descriptor(
  name='KlineQuoteDetail',
  full_name='MsgStockPull.KlineQuoteDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.KlineQuoteDetail.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.KlineQuoteDetail.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.KlineQuoteDetail.market', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='MsgStockPull.KlineQuoteDetail.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.KlineQuoteDetail.open', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='MsgStockPull.KlineQuoteDetail.high', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='MsgStockPull.KlineQuoteDetail.low', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='MsgStockPull.KlineQuoteDetail.close', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.KlineQuoteDetail.lastClose', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg', full_name='MsgStockPull.KlineQuoteDetail.avg', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.KlineQuoteDetail.change', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.KlineQuoteDetail.changePct', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.KlineQuoteDetail.volume', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.KlineQuoteDetail.amount', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4941,
  serialized_end=5180,
)


_MINUTEQUOTERESP = _descriptor.Descriptor(
  name='MinuteQuoteResp',
  full_name='MsgStockPull.MinuteQuoteResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.MinuteQuoteResp.lastClose', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='MsgStockPull.MinuteQuoteResp.minutes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5182,
  serialized_end=5267,
)


_TICKRESP = _descriptor.Descriptor(
  name='TickResp',
  full_name='MsgStockPull.TickResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.TickResp.lastClose', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteTickRespList', full_name='MsgStockPull.TickResp.quoteTickRespList', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5269,
  serialized_end=5351,
)


_TICKDETAIL = _descriptor.Descriptor(
  name='TickDetail',
  full_name='MsgStockPull.TickDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='MsgStockPull.TickDetail.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.TickDetail.assetId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.TickDetail.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.TickDetail.market', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='MsgStockPull.TickDetail.timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockPull.TickDetail.now', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curVolume', full_name='MsgStockPull.TickDetail.curVolume', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.TickDetail.amount', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickFlag', full_name='MsgStockPull.TickDetail.tickFlag', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickVi', full_name='MsgStockPull.TickDetail.tickVi', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5354,
  serialized_end=5529,
)


_TICKHISTORYRESP = _descriptor.Descriptor(
  name='TickHistoryResp',
  full_name='MsgStockPull.TickHistoryResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.TickHistoryResp.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.TickHistoryResp.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.TickHistoryResp.totalCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickList', full_name='MsgStockPull.TickHistoryResp.tickList', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5531,
  serialized_end=5643,
)


_BUYSELLLISTRESP = _descriptor.Descriptor(
  name='BuySellListResp',
  full_name='MsgStockPull.BuySellListResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BuySellListResp.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.BuySellListResp.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.BuySellListResp.market', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buyList', full_name='MsgStockPull.BuySellListResp.buyList', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellList', full_name='MsgStockPull.BuySellListResp.sellList', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5646,
  serialized_end=5799,
)


_BUYSELLLIST = _descriptor.Descriptor(
  name='BuySellList',
  full_name='MsgStockPull.BuySellList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='MsgStockPull.BuySellList.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerCount', full_name='MsgStockPull.BuySellList.brokerCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='MsgStockPull.BuySellList.price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.BuySellList.volume', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5801,
  serialized_end=5881,
)


_QUOTEINFOBROKERRESP = _descriptor.Descriptor(
  name='QuoteInfoBrokerResp',
  full_name='MsgStockPull.QuoteInfoBrokerResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.QuoteInfoBrokerResp.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockPull.QuoteInfoBrokerResp.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockPull.QuoteInfoBrokerResp.market', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buyList', full_name='MsgStockPull.QuoteInfoBrokerResp.buyList', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellList', full_name='MsgStockPull.QuoteInfoBrokerResp.sellList', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5884,
  serialized_end=6059,
)


_QUOTEINFOBROKERSTALL = _descriptor.Descriptor(
  name='QuoteInfoBrokerStall',
  full_name='MsgStockPull.QuoteInfoBrokerStall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokerLevel', full_name='MsgStockPull.QuoteInfoBrokerStall.brokerLevel', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerInfos', full_name='MsgStockPull.QuoteInfoBrokerStall.brokerInfos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6061,
  serialized_end=6160,
)


_QUOTEINFOBROKERINFO = _descriptor.Descriptor(
  name='QuoteInfoBrokerInfo',
  full_name='MsgStockPull.QuoteInfoBrokerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokerId', full_name='MsgStockPull.QuoteInfoBrokerInfo.brokerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerName', full_name='MsgStockPull.QuoteInfoBrokerInfo.brokerName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6162,
  serialized_end=6221,
)


_IPAGEPLATEQUOTA = _descriptor.Descriptor(
  name='IPagePlateQuota',
  full_name='MsgStockPull.IPagePlateQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='MsgStockPull.IPagePlateQuota.current', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='MsgStockPull.IPagePlateQuota.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='MsgStockPull.IPagePlateQuota.totalCount', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.IPagePlateQuota.subMarketCode', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plateQuota', full_name='MsgStockPull.IPagePlateQuota.plateQuota', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6224,
  serialized_end=6361,
)


_PLATEQUOTA = _descriptor.Descriptor(
  name='PlateQuota',
  full_name='MsgStockPull.PlateQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.PlateQuota.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonQuota', full_name='MsgStockPull.PlateQuota.commonQuota', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='popularQuota', full_name='MsgStockPull.PlateQuota.popularQuota', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simpleAssetInfo', full_name='MsgStockPull.PlateQuota.simpleAssetInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6364,
  serialized_end=6547,
)


_POPULARQUOTA = _descriptor.Descriptor(
  name='PopularQuota',
  full_name='MsgStockPull.PopularQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subPlateId', full_name='MsgStockPull.PopularQuota.subPlateId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPlateCode', full_name='MsgStockPull.PopularQuota.subPlateCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPlateName', full_name='MsgStockPull.PopularQuota.subPlateName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.PopularQuota.changePct', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.PopularQuota.change', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stkCode', full_name='MsgStockPull.PopularQuota.stkCode', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.PopularQuota.shortName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgChangePct', full_name='MsgStockPull.PopularQuota.avgChangePct', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatPlateCount', full_name='MsgStockPull.PopularQuota.flatPlateCount', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upPlateCount', full_name='MsgStockPull.PopularQuota.upPlateCount', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downPlateCount', full_name='MsgStockPull.PopularQuota.downPlateCount', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6550,
  serialized_end=6791,
)


_COMMONQUOTA = _descriptor.Descriptor(
  name='CommonQuota',
  full_name='MsgStockPull.CommonQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.CommonQuota.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basicQuote', full_name='MsgStockPull.CommonQuota.basicQuote', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonFinanceQuota', full_name='MsgStockPull.CommonQuota.commonFinanceQuota', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='otherQuotaExt', full_name='MsgStockPull.CommonQuota.otherQuotaExt', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6794,
  serialized_end=6988,
)


_OTHERQUOTAEXT = _descriptor.Descriptor(
  name='OtherQuotaExt',
  full_name='MsgStockPull.OtherQuotaExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outerDisk', full_name='MsgStockPull.OtherQuotaExt.outerDisk', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='innerDisk', full_name='MsgStockPull.OtherQuotaExt.innerDisk', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='risePrice', full_name='MsgStockPull.OtherQuotaExt.risePrice', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallPrice', full_name='MsgStockPull.OtherQuotaExt.fallPrice', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatPlateCount', full_name='MsgStockPull.OtherQuotaExt.flatPlateCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upPlateCount', full_name='MsgStockPull.OtherQuotaExt.upPlateCount', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downPlateCount', full_name='MsgStockPull.OtherQuotaExt.downPlateCount', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6991,
  serialized_end=7152,
)


_BASICFINANCEINFO = _descriptor.Descriptor(
  name='BasicFinanceInfo',
  full_name='MsgStockPull.BasicFinanceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicFinanceInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shareCapital', full_name='MsgStockPull.BasicFinanceInfo.shareCapital', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='circulationCapital', full_name='MsgStockPull.BasicFinanceInfo.circulationCapital', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='earningsPerShares', full_name='MsgStockPull.BasicFinanceInfo.earningsPerShares', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='netAssetPS', full_name='MsgStockPull.BasicFinanceInfo.netAssetPS', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendPerShareTotal', full_name='MsgStockPull.BasicFinanceInfo.dividendPerShareTotal', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commonFinanceQuota', full_name='MsgStockPull.BasicFinanceInfo.commonFinanceQuota', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7155,
  serialized_end=7380,
)


_COMMONFINANCEQUOTA = _descriptor.Descriptor(
  name='CommonFinanceQuota',
  full_name='MsgStockPull.CommonFinanceQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketValue', full_name='MsgStockPull.CommonFinanceQuota.marketValue', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turnoverRate', full_name='MsgStockPull.CommonFinanceQuota.turnoverRate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peRatio', full_name='MsgStockPull.CommonFinanceQuota.peRatio', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peRatioTTM', full_name='MsgStockPull.CommonFinanceQuota.peRatioTTM', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pbRatio', full_name='MsgStockPull.CommonFinanceQuota.pbRatio', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantityRatio', full_name='MsgStockPull.CommonFinanceQuota.quantityRatio', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committee', full_name='MsgStockPull.CommonFinanceQuota.committee', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='MsgStockPull.CommonFinanceQuota.amplitude', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negotiableValue', full_name='MsgStockPull.CommonFinanceQuota.negotiableValue', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendPerShare', full_name='MsgStockPull.CommonFinanceQuota.dividendPerShare', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dividendRatio', full_name='MsgStockPull.CommonFinanceQuota.dividendRatio', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highIn52Week', full_name='MsgStockPull.CommonFinanceQuota.highIn52Week', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowIn52Week', full_name='MsgStockPull.CommonFinanceQuota.lowIn52Week', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7383,
  serialized_end=7678,
)


_BASICQUOTEINFO = _descriptor.Descriptor(
  name='BasicQuoteInfo',
  full_name='MsgStockPull.BasicQuoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicQuoteInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockPull.BasicQuoteInfo.now', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.BasicQuoteInfo.open', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='MsgStockPull.BasicQuoteInfo.high', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='MsgStockPull.BasicQuoteInfo.low', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='MsgStockPull.BasicQuoteInfo.close', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose', full_name='MsgStockPull.BasicQuoteInfo.lastClose', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockPull.BasicQuoteInfo.volume', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockPull.BasicQuoteInfo.amount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgPrice', full_name='MsgStockPull.BasicQuoteInfo.avgPrice', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changeRate', full_name='MsgStockPull.BasicQuoteInfo.changeRate', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perVolumeInLast5TradeDay', full_name='MsgStockPull.BasicQuoteInfo.perVolumeInLast5TradeDay', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct', full_name='MsgStockPull.BasicQuoteInfo.changePct', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change', full_name='MsgStockPull.BasicQuoteInfo.change', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stockStatus', full_name='MsgStockPull.BasicQuoteInfo.stockStatus', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stockTime', full_name='MsgStockPull.BasicQuoteInfo.stockTime', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thisYearPct', full_name='MsgStockPull.BasicQuoteInfo.thisYearPct', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thisMonthPct', full_name='MsgStockPull.BasicQuoteInfo.thisMonthPct', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastYearClose', full_name='MsgStockPull.BasicQuoteInfo.lastYearClose', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastMonthClose', full_name='MsgStockPull.BasicQuoteInfo.lastMonthClose', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre5MinPrice', full_name='MsgStockPull.BasicQuoteInfo.pre5MinPrice', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose5Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose5Day', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose10Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose10Day', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose20Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose20Day', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose60Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose60Day', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose120Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose120Day', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastClose250Day', full_name='MsgStockPull.BasicQuoteInfo.lastClose250Day', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct5Minute', full_name='MsgStockPull.BasicQuoteInfo.changePct5Minute', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct5', full_name='MsgStockPull.BasicQuoteInfo.changePct5', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct10', full_name='MsgStockPull.BasicQuoteInfo.changePct10', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct20', full_name='MsgStockPull.BasicQuoteInfo.changePct20', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct60', full_name='MsgStockPull.BasicQuoteInfo.changePct60', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct120', full_name='MsgStockPull.BasicQuoteInfo.changePct120', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changePct250', full_name='MsgStockPull.BasicQuoteInfo.changePct250', index=33,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7681,
  serialized_end=8391,
)


_BASICASSETINFO = _descriptor.Descriptor(
  name='BasicAssetInfo',
  full_name='MsgStockPull.BasicAssetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assetId', full_name='MsgStockPull.BasicAssetInfo.assetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.BasicAssetInfo.shortName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stkCode', full_name='MsgStockPull.BasicAssetInfo.stkCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lotSize', full_name='MsgStockPull.BasicAssetInfo.lotSize', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusFlag', full_name='MsgStockPull.BasicAssetInfo.statusFlag', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listingDate', full_name='MsgStockPull.BasicAssetInfo.listingDate', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delistingDate', full_name='MsgStockPull.BasicAssetInfo.delistingDate', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priceDecimal', full_name='MsgStockPull.BasicAssetInfo.priceDecimal', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicAssetInfo.subMarketCode', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicAssetInfo.subMarketName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeCode', full_name='MsgStockPull.BasicAssetInfo.exchangeCode', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeName', full_name='MsgStockPull.BasicAssetInfo.exchangeName', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='industry', full_name='MsgStockPull.BasicAssetInfo.industry', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8394,
  serialized_end=8674,
)


_SIMPLEASSETINFO = _descriptor.Descriptor(
  name='SimpleAssetInfo',
  full_name='MsgStockPull.SimpleAssetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortName', full_name='MsgStockPull.SimpleAssetInfo.shortName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.SimpleAssetInfo.subMarketCode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.SimpleAssetInfo.subMarketName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8676,
  serialized_end=8758,
)


_BASICASSETINFOEXT = _descriptor.Descriptor(
  name='BasicAssetInfoExt',
  full_name='MsgStockPull.BasicAssetInfoExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicAssetInfoExt.subMarketCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicAssetInfoExt.subMarketName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketCode', full_name='MsgStockPull.BasicAssetInfoExt.marketCode', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketName', full_name='MsgStockPull.BasicAssetInfoExt.marketName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeCode', full_name='MsgStockPull.BasicAssetInfoExt.exchangeCode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeName', full_name='MsgStockPull.BasicAssetInfoExt.exchangeName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8761,
  serialized_end=8910,
)


_BASICSUBMARKETINFO = _descriptor.Descriptor(
  name='BasicSubMarketInfo',
  full_name='MsgStockPull.BasicSubMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketName', full_name='MsgStockPull.BasicSubMarketInfo.marketName', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketCode', full_name='MsgStockPull.BasicSubMarketInfo.subMarketCode', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketName', full_name='MsgStockPull.BasicSubMarketInfo.subMarketName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketEnName', full_name='MsgStockPull.BasicSubMarketInfo.subMarketEnName', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SubMarketTrName', full_name='MsgStockPull.BasicSubMarketInfo.SubMarketTrName', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subMarketTime', full_name='MsgStockPull.BasicSubMarketInfo.subMarketTime', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8913,
  serialized_end=9101,
)


_SUBMARKETTIME = _descriptor.Descriptor(
  name='SubMarketTime',
  full_name='MsgStockPull.SubMarketTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear', full_name='MsgStockPull.SubMarketTime.clear', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockPull.SubMarketTime.open', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='MsgStockPull.SubMarketTime.time_zone', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradeTime', full_name='MsgStockPull.SubMarketTime.tradeTime', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='MsgStockPull.SubMarketTime.close', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9103,
  serialized_end=9225,
)


_TRADETIME = _descriptor.Descriptor(
  name='TradeTime',
  full_name='MsgStockPull.TradeTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_start', full_name='MsgStockPull.TradeTime.trade_start', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_end', full_name='MsgStockPull.TradeTime.trade_end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9227,
  serialized_end=9278,
)


_ORDERONELEVELINFO = _descriptor.Descriptor(
  name='OrderOneLevelInfo',
  full_name='MsgStockPull.OrderOneLevelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buyPrice', full_name='MsgStockPull.OrderOneLevelInfo.buyPrice', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buyVolume', full_name='MsgStockPull.OrderOneLevelInfo.buyVolume', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellPrice', full_name='MsgStockPull.OrderOneLevelInfo.sellPrice', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sellVolume', full_name='MsgStockPull.OrderOneLevelInfo.sellVolume', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9280,
  serialized_end=9375,
)

_SUBMARKETPLATEREQ.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_SUBMARKETPLATEREQ.fields_by_name['language'].enum_type = stock__comm__pb2._LANGUAGE
_SUBMARKETPLATEREQ.fields_by_name['sortedFiled'].enum_type = _QUOTASORTEDFILED
_BASICMARKETINFOREQ.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_HANDICAPQUOTAREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_STOCKCODE.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_STOCKCODE.fields_by_name['language'].enum_type = stock__comm__pb2._LANGUAGE
_WARRANTREQ.fields_by_name['sortedFiled'].enum_type = _QUOTASORTEDFILED
_WARRANTREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_TRANSACTIONSTATREQ.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_KLINEREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_KLINEREQ.fields_by_name['quoteType'].enum_type = stock__comm__pb2._QUOTETYPE
_TICKREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_MINUTEQUOTEKREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_KLINEHISTORYREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_KLINEHISTORYREQ.fields_by_name['quoteType'].enum_type = stock__comm__pb2._QUOTETYPE
_TICKHISTORYREQ.fields_by_name['stockCode'].message_type = _STOCKCODE
_SUBMARKETASSETINFORESP.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_SUBMARKETASSETINFORESP.fields_by_name['pagePlateQuota'].message_type = _IPAGEPLATEQUOTA
_HANDICAPQUOTARESP.fields_by_name['handicapQuota'].message_type = _HANDICAPQUOTA
_HANDICAPQUOTA.fields_by_name['assetInfo'].message_type = _BASICASSETINFO
_HANDICAPQUOTA.fields_by_name['financeInfo'].message_type = _BASICFINANCEINFO
_HANDICAPQUOTA.fields_by_name['quoteInfo'].message_type = _BASICQUOTEINFO
_HANDICAPQUOTA.fields_by_name['otherQuotaExt'].message_type = _OTHERQUOTAEXT
_HANDICAPQUOTA.fields_by_name['oneLevelInfo'].message_type = _ORDERONELEVELINFO
_HANDICAPQUOTA.fields_by_name['warrantDetail'].message_type = _WARRANTDETAIL
_BASICMARKETINFORESP.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_BASICMARKETINFORESP.fields_by_name['basicAssetInfo'].message_type = _BASICASSETINFO
_BASICMARKETINFORESP.fields_by_name['basicSubMarketInfo'].message_type = _BASICSUBMARKETINFO
_WARRANTRESP.fields_by_name['warrant'].message_type = _WARRANTDETAIL
_WARRANTDETAIL.fields_by_name['simpleAssetInfo'].message_type = _SIMPLEASSETINFO
_WARRANTASSETINFORESP_WARRANTASSETDETAIL.containing_type = _WARRANTASSETINFORESP
_WARRANTASSETINFORESP.fields_by_name['warrant'].message_type = _WARRANTASSETINFORESP_WARRANTASSETDETAIL
_TRANSACTIONSTATRESP.fields_by_name['transactionStat'].message_type = _TRANSACTIONSTAT
_TRANSACTIONSTATRESP.fields_by_name['transactionInfo'].message_type = _TRANSACTIONSTATLIST
_DICDATARESP.fields_by_name['dicData'].message_type = _DICDATADETAIL
_AHQUOTARESP.fields_by_name['ahQuota'].message_type = _AHQUOTADETAIL
_EXCHANGERATERESP.fields_by_name['exchangeRate'].message_type = _EXCHANGERATEDETAIL
_KLINEQUOTERESP.fields_by_name['klineQuote'].message_type = _KLINEQUOTEDETAIL
_MINUTEQUOTERESP.fields_by_name['minutes'].message_type = _KLINEQUOTEDETAIL
_TICKRESP.fields_by_name['quoteTickRespList'].message_type = _TICKDETAIL
_TICKHISTORYRESP.fields_by_name['tickList'].message_type = _TICKDETAIL
_BUYSELLLISTRESP.fields_by_name['buyList'].message_type = _BUYSELLLIST
_BUYSELLLISTRESP.fields_by_name['sellList'].message_type = _BUYSELLLIST
_QUOTEINFOBROKERRESP.fields_by_name['buyList'].message_type = _QUOTEINFOBROKERSTALL
_QUOTEINFOBROKERRESP.fields_by_name['sellList'].message_type = _QUOTEINFOBROKERSTALL
_QUOTEINFOBROKERSTALL.fields_by_name['brokerInfos'].message_type = _QUOTEINFOBROKERINFO
_IPAGEPLATEQUOTA.fields_by_name['plateQuota'].message_type = _PLATEQUOTA
_PLATEQUOTA.fields_by_name['commonQuota'].message_type = _COMMONQUOTA
_PLATEQUOTA.fields_by_name['popularQuota'].message_type = _POPULARQUOTA
_PLATEQUOTA.fields_by_name['simpleAssetInfo'].message_type = _SIMPLEASSETINFO
_COMMONQUOTA.fields_by_name['basicQuote'].message_type = _BASICQUOTEINFO
_COMMONQUOTA.fields_by_name['commonFinanceQuota'].message_type = _COMMONFINANCEQUOTA
_COMMONQUOTA.fields_by_name['otherQuotaExt'].message_type = _OTHERQUOTAEXT
_BASICFINANCEINFO.fields_by_name['commonFinanceQuota'].message_type = _COMMONFINANCEQUOTA
_BASICSUBMARKETINFO.fields_by_name['subMarketTime'].message_type = _SUBMARKETTIME
_SUBMARKETTIME.fields_by_name['tradeTime'].message_type = _TRADETIME
DESCRIPTOR.message_types_by_name['SubMarketPlateReq'] = _SUBMARKETPLATEREQ
DESCRIPTOR.message_types_by_name['BasicMarketInfoReq'] = _BASICMARKETINFOREQ
DESCRIPTOR.message_types_by_name['HandicapQuotaReq'] = _HANDICAPQUOTAREQ
DESCRIPTOR.message_types_by_name['StockCode'] = _STOCKCODE
DESCRIPTOR.message_types_by_name['WarrantReq'] = _WARRANTREQ
DESCRIPTOR.message_types_by_name['WarrantAssetInfoReq'] = _WARRANTASSETINFOREQ
DESCRIPTOR.message_types_by_name['TransactionStatReq'] = _TRANSACTIONSTATREQ
DESCRIPTOR.message_types_by_name['DicDataReq'] = _DICDATAREQ
DESCRIPTOR.message_types_by_name['ExchangeRateReq'] = _EXCHANGERATEREQ
DESCRIPTOR.message_types_by_name['KLineReq'] = _KLINEREQ
DESCRIPTOR.message_types_by_name['TickReq'] = _TICKREQ
DESCRIPTOR.message_types_by_name['MinuteQuotekReq'] = _MINUTEQUOTEKREQ
DESCRIPTOR.message_types_by_name['KLineHistoryReq'] = _KLINEHISTORYREQ
DESCRIPTOR.message_types_by_name['TickHistoryReq'] = _TICKHISTORYREQ
DESCRIPTOR.message_types_by_name['SubMarketAssetInfoResp'] = _SUBMARKETASSETINFORESP
DESCRIPTOR.message_types_by_name['HandicapQuotaResp'] = _HANDICAPQUOTARESP
DESCRIPTOR.message_types_by_name['HandicapQuota'] = _HANDICAPQUOTA
DESCRIPTOR.message_types_by_name['BasicMarketInfoResp'] = _BASICMARKETINFORESP
DESCRIPTOR.message_types_by_name['WarrantResp'] = _WARRANTRESP
DESCRIPTOR.message_types_by_name['WarrantDetail'] = _WARRANTDETAIL
DESCRIPTOR.message_types_by_name['WarrantAssetInfoResp'] = _WARRANTASSETINFORESP
DESCRIPTOR.message_types_by_name['TransactionStatResp'] = _TRANSACTIONSTATRESP
DESCRIPTOR.message_types_by_name['DicDataResp'] = _DICDATARESP
DESCRIPTOR.message_types_by_name['DicDataDetail'] = _DICDATADETAIL
DESCRIPTOR.message_types_by_name['TransactionStat'] = _TRANSACTIONSTAT
DESCRIPTOR.message_types_by_name['TransactionStatList'] = _TRANSACTIONSTATLIST
DESCRIPTOR.message_types_by_name['AhQuotaResp'] = _AHQUOTARESP
DESCRIPTOR.message_types_by_name['AhQuotaDetail'] = _AHQUOTADETAIL
DESCRIPTOR.message_types_by_name['ExchangeRateResp'] = _EXCHANGERATERESP
DESCRIPTOR.message_types_by_name['ExchangeRateDetail'] = _EXCHANGERATEDETAIL
DESCRIPTOR.message_types_by_name['KlineQuoteResp'] = _KLINEQUOTERESP
DESCRIPTOR.message_types_by_name['KlineQuoteDetail'] = _KLINEQUOTEDETAIL
DESCRIPTOR.message_types_by_name['MinuteQuoteResp'] = _MINUTEQUOTERESP
DESCRIPTOR.message_types_by_name['TickResp'] = _TICKRESP
DESCRIPTOR.message_types_by_name['TickDetail'] = _TICKDETAIL
DESCRIPTOR.message_types_by_name['TickHistoryResp'] = _TICKHISTORYRESP
DESCRIPTOR.message_types_by_name['BuySellListResp'] = _BUYSELLLISTRESP
DESCRIPTOR.message_types_by_name['BuySellList'] = _BUYSELLLIST
DESCRIPTOR.message_types_by_name['QuoteInfoBrokerResp'] = _QUOTEINFOBROKERRESP
DESCRIPTOR.message_types_by_name['QuoteInfoBrokerStall'] = _QUOTEINFOBROKERSTALL
DESCRIPTOR.message_types_by_name['QuoteInfoBrokerInfo'] = _QUOTEINFOBROKERINFO
DESCRIPTOR.message_types_by_name['IPagePlateQuota'] = _IPAGEPLATEQUOTA
DESCRIPTOR.message_types_by_name['PlateQuota'] = _PLATEQUOTA
DESCRIPTOR.message_types_by_name['PopularQuota'] = _POPULARQUOTA
DESCRIPTOR.message_types_by_name['CommonQuota'] = _COMMONQUOTA
DESCRIPTOR.message_types_by_name['OtherQuotaExt'] = _OTHERQUOTAEXT
DESCRIPTOR.message_types_by_name['BasicFinanceInfo'] = _BASICFINANCEINFO
DESCRIPTOR.message_types_by_name['CommonFinanceQuota'] = _COMMONFINANCEQUOTA
DESCRIPTOR.message_types_by_name['BasicQuoteInfo'] = _BASICQUOTEINFO
DESCRIPTOR.message_types_by_name['BasicAssetInfo'] = _BASICASSETINFO
DESCRIPTOR.message_types_by_name['SimpleAssetInfo'] = _SIMPLEASSETINFO
DESCRIPTOR.message_types_by_name['BasicAssetInfoExt'] = _BASICASSETINFOEXT
DESCRIPTOR.message_types_by_name['BasicSubMarketInfo'] = _BASICSUBMARKETINFO
DESCRIPTOR.message_types_by_name['SubMarketTime'] = _SUBMARKETTIME
DESCRIPTOR.message_types_by_name['TradeTime'] = _TRADETIME
DESCRIPTOR.message_types_by_name['OrderOneLevelInfo'] = _ORDERONELEVELINFO
DESCRIPTOR.enum_types_by_name['QuotaSortedFiled'] = _QUOTASORTEDFILED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubMarketPlateReq = _reflection.GeneratedProtocolMessageType('SubMarketPlateReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETPLATEREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketPlateReq)
  })
_sym_db.RegisterMessage(SubMarketPlateReq)

BasicMarketInfoReq = _reflection.GeneratedProtocolMessageType('BasicMarketInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _BASICMARKETINFOREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicMarketInfoReq)
  })
_sym_db.RegisterMessage(BasicMarketInfoReq)

HandicapQuotaReq = _reflection.GeneratedProtocolMessageType('HandicapQuotaReq', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTAREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuotaReq)
  })
_sym_db.RegisterMessage(HandicapQuotaReq)

StockCode = _reflection.GeneratedProtocolMessageType('StockCode', (_message.Message,), {
  'DESCRIPTOR' : _STOCKCODE,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.StockCode)
  })
_sym_db.RegisterMessage(StockCode)

WarrantReq = _reflection.GeneratedProtocolMessageType('WarrantReq', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantReq)
  })
_sym_db.RegisterMessage(WarrantReq)

WarrantAssetInfoReq = _reflection.GeneratedProtocolMessageType('WarrantAssetInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTASSETINFOREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantAssetInfoReq)
  })
_sym_db.RegisterMessage(WarrantAssetInfoReq)

TransactionStatReq = _reflection.GeneratedProtocolMessageType('TransactionStatReq', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTATREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TransactionStatReq)
  })
_sym_db.RegisterMessage(TransactionStatReq)

DicDataReq = _reflection.GeneratedProtocolMessageType('DicDataReq', (_message.Message,), {
  'DESCRIPTOR' : _DICDATAREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.DicDataReq)
  })
_sym_db.RegisterMessage(DicDataReq)

ExchangeRateReq = _reflection.GeneratedProtocolMessageType('ExchangeRateReq', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.ExchangeRateReq)
  })
_sym_db.RegisterMessage(ExchangeRateReq)

KLineReq = _reflection.GeneratedProtocolMessageType('KLineReq', (_message.Message,), {
  'DESCRIPTOR' : _KLINEREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.KLineReq)
  })
_sym_db.RegisterMessage(KLineReq)

TickReq = _reflection.GeneratedProtocolMessageType('TickReq', (_message.Message,), {
  'DESCRIPTOR' : _TICKREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TickReq)
  })
_sym_db.RegisterMessage(TickReq)

MinuteQuotekReq = _reflection.GeneratedProtocolMessageType('MinuteQuotekReq', (_message.Message,), {
  'DESCRIPTOR' : _MINUTEQUOTEKREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.MinuteQuotekReq)
  })
_sym_db.RegisterMessage(MinuteQuotekReq)

KLineHistoryReq = _reflection.GeneratedProtocolMessageType('KLineHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _KLINEHISTORYREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.KLineHistoryReq)
  })
_sym_db.RegisterMessage(KLineHistoryReq)

TickHistoryReq = _reflection.GeneratedProtocolMessageType('TickHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _TICKHISTORYREQ,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TickHistoryReq)
  })
_sym_db.RegisterMessage(TickHistoryReq)

SubMarketAssetInfoResp = _reflection.GeneratedProtocolMessageType('SubMarketAssetInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETASSETINFORESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketAssetInfoResp)
  })
_sym_db.RegisterMessage(SubMarketAssetInfoResp)

HandicapQuotaResp = _reflection.GeneratedProtocolMessageType('HandicapQuotaResp', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTARESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuotaResp)
  })
_sym_db.RegisterMessage(HandicapQuotaResp)

HandicapQuota = _reflection.GeneratedProtocolMessageType('HandicapQuota', (_message.Message,), {
  'DESCRIPTOR' : _HANDICAPQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.HandicapQuota)
  })
_sym_db.RegisterMessage(HandicapQuota)

BasicMarketInfoResp = _reflection.GeneratedProtocolMessageType('BasicMarketInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _BASICMARKETINFORESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicMarketInfoResp)
  })
_sym_db.RegisterMessage(BasicMarketInfoResp)

WarrantResp = _reflection.GeneratedProtocolMessageType('WarrantResp', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantResp)
  })
_sym_db.RegisterMessage(WarrantResp)

WarrantDetail = _reflection.GeneratedProtocolMessageType('WarrantDetail', (_message.Message,), {
  'DESCRIPTOR' : _WARRANTDETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantDetail)
  })
_sym_db.RegisterMessage(WarrantDetail)

WarrantAssetInfoResp = _reflection.GeneratedProtocolMessageType('WarrantAssetInfoResp', (_message.Message,), {

  'WarrantAssetDetail' : _reflection.GeneratedProtocolMessageType('WarrantAssetDetail', (_message.Message,), {
    'DESCRIPTOR' : _WARRANTASSETINFORESP_WARRANTASSETDETAIL,
    '__module__' : 'stock_his_pb2'
    # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantAssetInfoResp.WarrantAssetDetail)
    })
  ,
  'DESCRIPTOR' : _WARRANTASSETINFORESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.WarrantAssetInfoResp)
  })
_sym_db.RegisterMessage(WarrantAssetInfoResp)
_sym_db.RegisterMessage(WarrantAssetInfoResp.WarrantAssetDetail)

TransactionStatResp = _reflection.GeneratedProtocolMessageType('TransactionStatResp', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTATRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TransactionStatResp)
  })
_sym_db.RegisterMessage(TransactionStatResp)

DicDataResp = _reflection.GeneratedProtocolMessageType('DicDataResp', (_message.Message,), {
  'DESCRIPTOR' : _DICDATARESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.DicDataResp)
  })
_sym_db.RegisterMessage(DicDataResp)

DicDataDetail = _reflection.GeneratedProtocolMessageType('DicDataDetail', (_message.Message,), {
  'DESCRIPTOR' : _DICDATADETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.DicDataDetail)
  })
_sym_db.RegisterMessage(DicDataDetail)

TransactionStat = _reflection.GeneratedProtocolMessageType('TransactionStat', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTAT,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TransactionStat)
  })
_sym_db.RegisterMessage(TransactionStat)

TransactionStatList = _reflection.GeneratedProtocolMessageType('TransactionStatList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTATLIST,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TransactionStatList)
  })
_sym_db.RegisterMessage(TransactionStatList)

AhQuotaResp = _reflection.GeneratedProtocolMessageType('AhQuotaResp', (_message.Message,), {
  'DESCRIPTOR' : _AHQUOTARESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.AhQuotaResp)
  })
_sym_db.RegisterMessage(AhQuotaResp)

AhQuotaDetail = _reflection.GeneratedProtocolMessageType('AhQuotaDetail', (_message.Message,), {
  'DESCRIPTOR' : _AHQUOTADETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.AhQuotaDetail)
  })
_sym_db.RegisterMessage(AhQuotaDetail)

ExchangeRateResp = _reflection.GeneratedProtocolMessageType('ExchangeRateResp', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATERESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.ExchangeRateResp)
  })
_sym_db.RegisterMessage(ExchangeRateResp)

ExchangeRateDetail = _reflection.GeneratedProtocolMessageType('ExchangeRateDetail', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEDETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.ExchangeRateDetail)
  })
_sym_db.RegisterMessage(ExchangeRateDetail)

KlineQuoteResp = _reflection.GeneratedProtocolMessageType('KlineQuoteResp', (_message.Message,), {
  'DESCRIPTOR' : _KLINEQUOTERESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.KlineQuoteResp)
  })
_sym_db.RegisterMessage(KlineQuoteResp)

KlineQuoteDetail = _reflection.GeneratedProtocolMessageType('KlineQuoteDetail', (_message.Message,), {
  'DESCRIPTOR' : _KLINEQUOTEDETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.KlineQuoteDetail)
  })
_sym_db.RegisterMessage(KlineQuoteDetail)

MinuteQuoteResp = _reflection.GeneratedProtocolMessageType('MinuteQuoteResp', (_message.Message,), {
  'DESCRIPTOR' : _MINUTEQUOTERESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.MinuteQuoteResp)
  })
_sym_db.RegisterMessage(MinuteQuoteResp)

TickResp = _reflection.GeneratedProtocolMessageType('TickResp', (_message.Message,), {
  'DESCRIPTOR' : _TICKRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TickResp)
  })
_sym_db.RegisterMessage(TickResp)

TickDetail = _reflection.GeneratedProtocolMessageType('TickDetail', (_message.Message,), {
  'DESCRIPTOR' : _TICKDETAIL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TickDetail)
  })
_sym_db.RegisterMessage(TickDetail)

TickHistoryResp = _reflection.GeneratedProtocolMessageType('TickHistoryResp', (_message.Message,), {
  'DESCRIPTOR' : _TICKHISTORYRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TickHistoryResp)
  })
_sym_db.RegisterMessage(TickHistoryResp)

BuySellListResp = _reflection.GeneratedProtocolMessageType('BuySellListResp', (_message.Message,), {
  'DESCRIPTOR' : _BUYSELLLISTRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BuySellListResp)
  })
_sym_db.RegisterMessage(BuySellListResp)

BuySellList = _reflection.GeneratedProtocolMessageType('BuySellList', (_message.Message,), {
  'DESCRIPTOR' : _BUYSELLLIST,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BuySellList)
  })
_sym_db.RegisterMessage(BuySellList)

QuoteInfoBrokerResp = _reflection.GeneratedProtocolMessageType('QuoteInfoBrokerResp', (_message.Message,), {
  'DESCRIPTOR' : _QUOTEINFOBROKERRESP,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.QuoteInfoBrokerResp)
  })
_sym_db.RegisterMessage(QuoteInfoBrokerResp)

QuoteInfoBrokerStall = _reflection.GeneratedProtocolMessageType('QuoteInfoBrokerStall', (_message.Message,), {
  'DESCRIPTOR' : _QUOTEINFOBROKERSTALL,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.QuoteInfoBrokerStall)
  })
_sym_db.RegisterMessage(QuoteInfoBrokerStall)

QuoteInfoBrokerInfo = _reflection.GeneratedProtocolMessageType('QuoteInfoBrokerInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUOTEINFOBROKERINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.QuoteInfoBrokerInfo)
  })
_sym_db.RegisterMessage(QuoteInfoBrokerInfo)

IPagePlateQuota = _reflection.GeneratedProtocolMessageType('IPagePlateQuota', (_message.Message,), {
  'DESCRIPTOR' : _IPAGEPLATEQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.IPagePlateQuota)
  })
_sym_db.RegisterMessage(IPagePlateQuota)

PlateQuota = _reflection.GeneratedProtocolMessageType('PlateQuota', (_message.Message,), {
  'DESCRIPTOR' : _PLATEQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.PlateQuota)
  })
_sym_db.RegisterMessage(PlateQuota)

PopularQuota = _reflection.GeneratedProtocolMessageType('PopularQuota', (_message.Message,), {
  'DESCRIPTOR' : _POPULARQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.PopularQuota)
  })
_sym_db.RegisterMessage(PopularQuota)

CommonQuota = _reflection.GeneratedProtocolMessageType('CommonQuota', (_message.Message,), {
  'DESCRIPTOR' : _COMMONQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.CommonQuota)
  })
_sym_db.RegisterMessage(CommonQuota)

OtherQuotaExt = _reflection.GeneratedProtocolMessageType('OtherQuotaExt', (_message.Message,), {
  'DESCRIPTOR' : _OTHERQUOTAEXT,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.OtherQuotaExt)
  })
_sym_db.RegisterMessage(OtherQuotaExt)

BasicFinanceInfo = _reflection.GeneratedProtocolMessageType('BasicFinanceInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICFINANCEINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicFinanceInfo)
  })
_sym_db.RegisterMessage(BasicFinanceInfo)

CommonFinanceQuota = _reflection.GeneratedProtocolMessageType('CommonFinanceQuota', (_message.Message,), {
  'DESCRIPTOR' : _COMMONFINANCEQUOTA,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.CommonFinanceQuota)
  })
_sym_db.RegisterMessage(CommonFinanceQuota)

BasicQuoteInfo = _reflection.GeneratedProtocolMessageType('BasicQuoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICQUOTEINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicQuoteInfo)
  })
_sym_db.RegisterMessage(BasicQuoteInfo)

BasicAssetInfo = _reflection.GeneratedProtocolMessageType('BasicAssetInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICASSETINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicAssetInfo)
  })
_sym_db.RegisterMessage(BasicAssetInfo)

SimpleAssetInfo = _reflection.GeneratedProtocolMessageType('SimpleAssetInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEASSETINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SimpleAssetInfo)
  })
_sym_db.RegisterMessage(SimpleAssetInfo)

BasicAssetInfoExt = _reflection.GeneratedProtocolMessageType('BasicAssetInfoExt', (_message.Message,), {
  'DESCRIPTOR' : _BASICASSETINFOEXT,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicAssetInfoExt)
  })
_sym_db.RegisterMessage(BasicAssetInfoExt)

BasicSubMarketInfo = _reflection.GeneratedProtocolMessageType('BasicSubMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _BASICSUBMARKETINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.BasicSubMarketInfo)
  })
_sym_db.RegisterMessage(BasicSubMarketInfo)

SubMarketTime = _reflection.GeneratedProtocolMessageType('SubMarketTime', (_message.Message,), {
  'DESCRIPTOR' : _SUBMARKETTIME,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.SubMarketTime)
  })
_sym_db.RegisterMessage(SubMarketTime)

TradeTime = _reflection.GeneratedProtocolMessageType('TradeTime', (_message.Message,), {
  'DESCRIPTOR' : _TRADETIME,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.TradeTime)
  })
_sym_db.RegisterMessage(TradeTime)

OrderOneLevelInfo = _reflection.GeneratedProtocolMessageType('OrderOneLevelInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERONELEVELINFO,
  '__module__' : 'stock_his_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockPull.OrderOneLevelInfo)
  })
_sym_db.RegisterMessage(OrderOneLevelInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
